@@ -224,6 +224,7 @@ bool BookmarkManager::addBookmark( const KUrl& referurl, const Okular::DocumentV
     KUrl newurl = referurl;
     newurl.setHTMLRef( vp.toString() );
     it.value().addBookmark( newtitle, newurl, QString() );
+    d->urlBookmarks.insert( vp.pageNumber );
     foreachObserver( notifyPageChanged( vp.pageNumber, DocumentObserver::Bookmark ) );
     return true;
 }
@@ -251,6 +252,7 @@ int BookmarkManager::removeBookmark( const KUrl& referurl, const KBookmark& bm )
         return -1;
 
     it.value().deleteBookmark( bm );
+    d->urlBookmarks.remove( vp.pageNumber );
 
     foreachObserver( notifyPageChanged( vp.pageNumber, DocumentObserver::Bookmark ) );
 
