@@ -301,12 +301,12 @@ QWidget * LineAnnotationWidget::widget()
     gb->setTitle( i18n( "Line Extensions" ) );
     QGridLayout * gridlay = new QGridLayout( gb );
     QLabel * tmplabel = new QLabel( i18n( "Leader Line Length:" ), gb );
-    gridlay->addWidget( tmplabel, 0, 0 );
+    gridlay->addWidget( tmplabel, 0, 0, Qt::AlignRight );
     m_spinLL = new QDoubleSpinBox( gb );
     gridlay->addWidget( m_spinLL, 0, 1 );
     tmplabel->setBuddy( m_spinLL );
     tmplabel = new QLabel( i18n( "Leader Line Extensions Length:" ), gb );
-    gridlay->addWidget( tmplabel, 1, 0 );
+    gridlay->addWidget( tmplabel, 1, 0, Qt::AlignRight );
     m_spinLLE = new QDoubleSpinBox( gb );
     gridlay->addWidget( m_spinLLE, 1, 1 );
     tmplabel->setBuddy( m_spinLLE );
@@ -317,7 +317,7 @@ QWidget * LineAnnotationWidget::widget()
     gb2->setTitle( i18n( "Style" ) );
     QGridLayout * gridlay2 = new QGridLayout( gb2 );
     QLabel * tmplabel2 = new QLabel( i18n( "&Size:" ), gb2 );
-    gridlay2->addWidget( tmplabel2, 0, 0 );
+    gridlay2->addWidget( tmplabel2, 0, 0, Qt::AlignRight );
     m_spinSize = new QDoubleSpinBox( gb2 );
     gridlay2->addWidget( m_spinSize, 0, 1 );
     tmplabel2->setBuddy( m_spinSize );
@@ -371,7 +371,7 @@ QWidget * HighlightAnnotationWidget::widget()
     QHBoxLayout * typelay = new QHBoxLayout();
     lay->addLayout( typelay );
     QLabel * tmplabel = new QLabel( i18n( "Type:" ), m_widget );
-    typelay->addWidget( tmplabel );
+    typelay->addWidget( tmplabel, 0, Qt::AlignRight );
     m_typeCombo = new QComboBox( m_widget );
     tmplabel->setBuddy( m_typeCombo );
     typelay->addWidget( m_typeCombo );
@@ -409,7 +409,7 @@ QWidget * GeomAnnotationWidget::widget()
     QGridLayout * lay = new QGridLayout( m_widget );
     lay->setMargin( 0 );
     QLabel * tmplabel = new QLabel( i18n( "Type:" ), m_widget );
-    lay->addWidget( tmplabel, 0, 0 );
+    lay->addWidget( tmplabel, 0, 0, Qt::AlignRight );
     m_typeCombo = new QComboBox( m_widget );
     tmplabel->setBuddy( m_typeCombo );
     lay->addWidget( m_typeCombo, 0, 1 );
