@@ -22,6 +22,7 @@
 #include <qtimer.h>
 #include <qtoolbutton.h>
 #include <kacceleratormanager.h>
+#include <kcolorscheme.h>
 #include <kiconloader.h>
 #include <klocale.h>
 
@@ -46,7 +47,7 @@ PageViewItem::PageViewItem( const Okular::Page * page )
 
 PageViewItem::~PageViewItem()
 {
-    QHash<QString, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
+    QHash<int, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
     for ( ; it != itEnd; ++it )
         delete *it;
 }
@@ -86,7 +87,7 @@ bool PageViewItem::isVisible() const
     return m_visible;
 }
 
-QHash<QString, FormWidgetIface*>& PageViewItem::formWidgets()
+QHash<int, FormWidgetIface*>& PageViewItem::formWidgets()
 {
     return m_formWidgets;
 }
@@ -112,7 +113,7 @@ void PageViewItem::moveTo( int x, int y )
 {
     m_geometry.moveLeft( x );
     m_geometry.moveTop( y );
-    QHash<QString, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
+    QHash<int, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
     for ( ; it != itEnd; ++it )
     {
         Okular::NormalizedRect r = (*it)->rect();
@@ -139,7 +140,7 @@ bool PageViewItem::setFormWidgetsVisible( bool visible )
         return false;
 
     bool somehadfocus = false;
-    QHash<QString, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
+    QHash<int, FormWidgetIface*>::iterator it = m_formWidgets.begin(), itEnd = m_formWidgets.end();
     for ( ; it != itEnd; ++it )
     {
         bool hadfocus = (*it)->setVisibility( visible );
@@ -293,10 +294,8 @@ PageViewTopMessage::PageViewTopMessage( QWidget * parent )
 {
     setAutoFillBackground( true );
     QPalette pal = palette();
-    pal.setColor( QPalette::Active, QPalette::Window, Qt::yellow );
-    pal.setColor( QPalette::Inactive, QPalette::Window, Qt::yellow );
-    pal.setColor( QPalette::Disabled, QPalette::Window, Qt::yellow );
-    pal.setColor( QPalette::WindowText, Qt::black );
+    KColorScheme::adjustBackground( pal, KColorScheme::NeutralBackground, QPalette::Window );
+    KColorScheme::adjustForeground( pal, KColorScheme::NeutralText, QPalette::Text );
     setPalette( pal );
     QHBoxLayout * lay = new QHBoxLayout( this );
     lay->setMargin( 4 );
